Module lists

Module lists 

Functions

alist_from
Makes an alist from the given arguments.
alist_get
Finds the first association (key . value) by comparing key with alist elements, and, if found, returns the value of that association.
assoc
Returns the first association for key in alist, comparing key against the alist elements using testfn if it is a function, and equal otherwise.
last
Returns the last link in the given list.
length
Returns the number of elements in the given list.
nth
Returns the n-th element in the given list.
nthcdr
Repeatedly takes the the CDR of the list n-times, and returns the n-th cdr of the given list.
plist_from
Makes a plist from the given arguments.
plist_get
Returns the value of the property property stored in the property list plist.